@@ -4,30 +4,51 @@ from Solution import Solution
 import tools
 
 def solve(bvp_problem,
-               solution_guess,
-               initial_mesh = None,
-               parameter_guess = None,
-               max_subintervals = 300,
-               singular_term = None,
-               tolerence = 1e-6,
-               method = 4,
-               trace = 0,
-               error_on_fail = True):
-    """
-    Attempts to solve the supplied boundary value problem starting from the user-supplied guess for the solution using BVP_SOLVER.
+          solution_guess,
+          initial_mesh = None,
+          parameter_guess = None,
+          max_subintervals = 300,
+          singular_term = None,
+          tolerance = 1.0e-6,
+          method = 4,
+          trace = 0,
+          error_on_fail = True):
+    """Attempts to solve the supplied boundary value problem starting from the user supplied guess for the solution using BVP_SOLVER.
 
-    bvp_problem - (required) a ProblemDefinition object which defines the boundary value problem to be solved.
-    solution_guess - (required) a guess for the solution, can either be a Solution object, a constant or an array of values or a function.
-    [initial_mesh] - an array (or castable) of points on the x-axis to use, default is 10 evenly spaced points.
-                    Must not be supplied if solution_guess is a Solution object.
-    parameter_guess - an array (or castable) of guesses for the unknown parameters.
-                    Must not be supplied if solution_guess is a Solution object.
-    [max_subintervals] - maximum number of points on the mesh before an error is returned. Default is 300
-    [singular_term] - array (or castable) that defines the singular term for the problem if one exist. Default is None.
-    [tolerence] - Default is 1e-6
-    [method ] - order of Runge-Kutta to use. Must be either 2, 4 or 6. Default is 4.
-    [trace] - indicates verbosity of output. 0 for no output, 1 for some output, 2 for full output. Default is 0.
-    [error_on_fail] - indicates whether an exception should be raised if solving fails. Default is True.
+    Parameters
+    ----------
+    bvp_problem : :class:`ProblemDefinition`
+        Defines the boundary value problem to be solved.
+    solution_guess : :class:`Solution`, constant, array of values or function
+        A guess for the solution.
+    initial_mesh : castable to floating point ndarray
+        Points on the x-axis to use for the supplied solution guess, default is 10 evenly spaced points. Must not be supplied if solution_guess is a :class:`Solution` object.
+    parameter_guess : castable to floating point ndarray, shape (num_parameters)
+        Guesses for the unknown parameters. Must not be supplied if solution_guess is a :class:`Solution` object.
+    max_subintervals : int
+        Maximum number of points on the mesh before an error is returned.
+    singular_term : castable to floating point ndarray, shape(num_ODE, num_ODE)
+        Matrix that defines the singular term for the problem if one exist.
+    tolerance : positive float
+        Tolerance for size of defect of approximate solution.
+    method : {2, 4, 6}
+        Order of Runge-Kutta to use.
+    trace : {0, 1, 2}
+        Indicates verbosity of output. 0 for no output, 1 for some output, 2 for full output.
+    error_on_fail : logical
+        Indicates whether an exception should be raised if solving fails.
+
+    Returns
+    -------
+    sol : :class:`Solution`
+        Approximate problem solution.
+
+    Raises
+    ------
+    ValueError
+        If bvp_problem failed validation in some way.
+    ValueError
+        If solving fails.
     """
 
     init_solution = 0
@@ -88,9 +109,9 @@ def solve(bvp_problem,
 
 
     if not (method == 2 or method == 4 or method == 6 ):
-        raise ValueError ("method must be either 2, 4 or 6 but got " + method )
+        raise ValueError ("method must be either 2, 4 or 6 but got " + str(method) )
 
-    if (tolerence < 0):
+    if (tolerance < 0):
         raise ValueError("tolerance must be nonnegative")
 
     singular = not (singular_term is None)
@@ -105,36 +126,37 @@ def solve(bvp_problem,
 
     # test the problem specifications with the initial solution
     bvp_problem.test(init_solution)
+                                    
+                                
+                    
+    bvp_solverf.bvp.bvp_solver_wrap(node_in = bvp_problem.num_ODE,
+                                    npar_in = bvp_problem.num_parameters,
+                                    leftbc_in = bvp_problem.num_left_boundary_conditions,
+                                    npts_in = len(init_solution.mesh),
+                                    info_in = init_solution.successIndicator,
+                                    mxnsub_in = max_subintervals,
+                                    x_in = tools.farg(init_solution.mesh),
+                                    y_in = tools.farg(init_solution.solution),
+                                    parameters_in = tools.farg(init_solution.parameters),
+                                    work_in = tools.farg(init_solution.work),
+                                    iwork_in = tools.farg(init_solution.iwork),
+                                    fsub = bvp_problem._function,
+                                    fsubp = bvp_problem._functionp,
+                                    bcsub = bvp_problem._boundary_conditions,
+                                    bcsubp = bvp_problem._boundary_conditionsp,
 
+                                    singular = singular,
 
-    bvp_solverf.bvp.bvp_solver_wrap(bvp_problem.num_ODE,
-                                    bvp_problem.num_parameters,
-                                    bvp_problem.num_left_boundary_conditions,
-                                    len(init_solution.mesh),
-                                    init_solution.successIndicator,
-                                    max_subintervals,
-                                    tools.farg(init_solution.mesh),
-                                    tools.farg(init_solution.solution),
-                                    tools.farg(init_solution.parameters),
-                                    tools.farg(init_solution.work),
-                                    tools.farg(init_solution.iwork),
-                                    bvp_problem.function,
-                                    bvp_problem.functionp,
-                                    bvp_problem.boundary_conditions,
-                                    bvp_problem.boundary_conditionsp,
+                                    hasdfdy = bvp_problem.has_function_derivative,
+                                    dfdy = bvp_problem._function_derivative,
+                                    dfdyp = bvp_problem._function_derivativep,
 
-                                    singular,
-
-                                    bvp_problem.has_function_derivative,
-                                    bvp_problem.function_derivative,
-                                    bvp_problem.function_derivativep,
-
-                                    bvp_problem.has_boundary_conditions_derivative,
-                                    bvp_problem.boundary_conditions_derivative,
-                                    bvp_problem.boundary_conditions_derivativep,
+                                    hasdbcdy = bvp_problem.has_boundary_conditions_derivative,
+                                    dbcdy = bvp_problem._boundary_conditions_derivative,
+                                    dbcdyp = bvp_problem._boundary_conditions_derivativep,
                                     #optional arguments
                                     method = method,
-                                    tol = tolerence,
+                                    tol = tolerance,
 
                                     trace = trace,
                                     # we never want the actual program to shut down from the fortran side, we should throw an error
@@ -145,7 +167,7 @@ def solve(bvp_problem,
     calculatedSolution = Solution.from_arg_list(bvp_solverf.bvp)
 
     # check to see if there was a problem with the solution
-    if error_on_fail and calculatedSolution.successIndicator == -1:
+    if error_on_fail and calculatedSolution._successIndicator == -1:
         raise ValueError("Boundary value problem solving failed. Run with trace = 1 or 2 for more information.")
 
     return calculatedSolution
\ No newline at end of file
